<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);
include('inc/config.php');
 date_default_timezone_set("Asia/Calcutta");
 $fromdate = date('Y-m-d H:i:s');  
// Ensure the request method is POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'];

    // Prepared statement and user input handling for Create and Update actions
    if ($action === 'Create' || $action === 'Update') {
        // Sanitize and collect form data using prepared statements
        $doctorID = mysqli_real_escape_string($conn, $_POST['DoctorID']);
        $patientID = mysqli_real_escape_string($conn, $_POST['PatientID']);
        $aDate = mysqli_real_escape_string($conn, $_POST['Date']);
        $aTime = mysqli_real_escape_string($conn, $_POST['Time']);
        $shiftNumber = mysqli_real_escape_string($conn, $_POST['ShiftNumber']);
        $isPaid = mysqli_real_escape_string($conn, $_POST['IsPaid']);
        $transactionID = mysqli_real_escape_string($conn, $_POST['TransactionID']);
        $status = mysqli_real_escape_string($conn, $_POST['Status']);
        $id = mysqli_real_escape_string($conn, $_POST['id'] ?? null);
        $useridnew = mysqli_real_escape_string($conn, $_POST['useridnew'] ?? null);
        $rolenew = mysqli_real_escape_string($conn, $_POST['rolenew'] ?? null);

        // Validate input data
        if (!$doctorID || !$patientID) {
            echo json_encode(['status' => 'Error', 'message' => 'Missing required input']);
            exit;
        }
        
        // Create action
       if ($action === 'Create') {
   

    // Check for duplicates
    $checkDuplicate = "SELECT * FROM Appointments WHERE DoctorID = ? AND PatientID = ? AND Date = ? AND Time = ? AND (Status != 'Cancelled' AND Status != 'Rescheduled')";
    $stmt = mysqli_prepare($conn, $checkDuplicate);
    mysqli_stmt_bind_param($stmt, 'iiss', $doctorID, $patientID, $aDate, $aTime);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);

    if (mysqli_num_rows($result) > 0) {
        echo json_encode(['status' => 'Duplicate', 'message' => 'Appointment already exists for this patient.']);
        exit;
    }

    // Insert new appointment
    $insertQuery = "INSERT INTO Appointments (DoctorID, PatientID, Date, Time, ShiftNumber, IsPaid, TransactionID, Status, created_at, UserId, UserRole) 
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
    $stmt = mysqli_prepare($conn, $insertQuery);
    
    // Use 's' for the created_at date, as it is a string
    mysqli_stmt_bind_param($stmt, 'iisssisssss', $doctorID, $patientID, $aDate, $aTime, $shiftNumber, $isPaid, $transactionID, $status, $fromdate, $useridnew, $rolenew);

    // Execute the statement
    if (mysqli_stmt_execute($stmt)) {
        echo json_encode(['status' => 'Create']);
    } else {
        echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
    }
}


        // Update action
        elseif ($action === 'Update' && $id) {
            // Check for duplicate rescheduled appointments
            if ($status === 'Rescheduled') {
                $checkDuplicate = "SELECT * FROM Appointments WHERE DoctorID = ? AND PatientID = ? AND Date = ? AND Time = ? AND (Status != 'Cancelled' AND Status != 'Rescheduled') AND AppointmentID != ?";
                $stmt = mysqli_prepare($conn, $checkDuplicate);
                mysqli_stmt_bind_param($stmt, 'iissi', $doctorID, $patientID, $aDate, $aTime, $id);
                mysqli_stmt_execute($stmt);
                $result = mysqli_stmt_get_result($stmt);

                if (mysqli_num_rows($result) > 0) {
                    echo json_encode(['status' => 'Duplicate', 'message' => 'Another appointment already exists with the same details.']);
                    exit;
                }

                // Insert new appointment and update the original appointment to 'Rescheduled'
                $insertQuery = "INSERT INTO Appointments (DoctorID, PatientID, Date, Time, ShiftNumber, IsPaid, TransactionID, Status, created_at, UserId, UserRole) 
                VALUES (?, ?, ?, ?, ?, ?, ?, 'Not Visited', ?, ?, ?)";
                $stmt = mysqli_prepare($conn, $insertQuery);
                mysqli_stmt_bind_param($stmt, 'iisssissis', $doctorID, $patientID, $aDate, $aTime, $shiftNumber, $isPaid, $transactionID, $fromdate, $useridnew, $rolenew);
                
                if (mysqli_stmt_execute($stmt)) {
                    $newAppointmentId = mysqli_insert_id($conn);

                    // Update original appointment to 'Rescheduled'
                    $updateQuery = "UPDATE Appointments SET Status = 'Rescheduled',UpdatedAt = ?, RescheduledAppointmentID = ? WHERE AppointmentID = ?";
                    $stmt_update = mysqli_prepare($conn, $updateQuery);
                    mysqli_stmt_bind_param($stmt_update, 'sii', $fromdate, $newAppointmentId, $id);

                    if (mysqli_stmt_execute($stmt_update)) {
                        echo json_encode(['status' => 'Rescheduled', 'newAppointmentId' => $newAppointmentId, 'message' => 'Appointment rescheduled successfully.']);
                    } else {
                        echo json_encode(['status' => 'Error', 'message' => 'Failed to update original appointment: ' . mysqli_error($conn)]);
                    }
                } else {
                    echo json_encode(['status' => 'Error', 'message' => 'Failed to insert new appointment: ' . mysqli_error($conn)]);
                }
            } else {
                // Regular update logic
                $checkDuplicate = "SELECT * FROM Appointments WHERE DoctorID = ? AND PatientID = ? AND Date = ? AND Time = ? AND AppointmentID != ?";
                $stmt = mysqli_prepare($conn, $checkDuplicate);
                mysqli_stmt_bind_param($stmt, 'iissi', $doctorID, $patientID, $aDate, $aTime, $id);
                mysqli_stmt_execute($stmt);
                $result = mysqli_stmt_get_result($stmt);

                if (mysqli_num_rows($result) > 0) {
                    echo json_encode(['status' => 'Duplicate', 'message' => 'Another appointment already exists with the same details.']);
                    exit;
                }

                // Update appointment
                $updateQuery = "UPDATE Appointments SET DoctorID = ?, PatientID = ?, IsPaid = ?, TransactionID = ?, Status = ?, UpdatedAt = ? WHERE AppointmentID = ?";
                $stmt = mysqli_prepare($conn, $updateQuery);
                 mysqli_stmt_bind_param($stmt, 'iissssi', $doctorID, $patientID, $isPaid, $transactionID, $status, $fromdate, $id);
                if (mysqli_stmt_execute($stmt)) {
                    echo json_encode(['status' => 'Update']);
                } else {
                    echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
                }
            }
        }
    }

    // Select action
    if ($action === 'Select' && isset($_POST['id'])) {
        $id = filter_var($_POST['id'], FILTER_SANITIZE_NUMBER_INT);
        $query = "SELECT a.AppointmentID, a.DoctorID, a.PatientID, a.Date, a.Time, a.IsPaid, a.TransactionID, a.Status, 
                  p.PatientName FROM Appointments a JOIN Patients p ON a.PatientID = p.PatientID WHERE a.AppointmentID = ?";
        $stmt = mysqli_prepare($conn, $query);
        mysqli_stmt_bind_param($stmt, 'i', $id);
        mysqli_stmt_execute($stmt);
        $result = mysqli_stmt_get_result($stmt);

        if ($result && mysqli_num_rows($result) > 0) {
            $row = mysqli_fetch_assoc($result);
            echo json_encode($row);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found.']);
        }
    }

    // Delete action
    if ($action === 'Delete' && isset($_POST['id'])) {
        $id = filter_var($_POST['id'], FILTER_SANITIZE_NUMBER_INT);
        $sql_delete = "DELETE FROM Appointments WHERE AppointmentID = ?";
        $stmt = mysqli_prepare($conn, $sql_delete);
        mysqli_stmt_bind_param($stmt, 'i', $id);

        if (mysqli_stmt_execute($stmt)) {
            echo json_encode(['status' => 'Delete', 'message' => 'Record deleted successfully']);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Error deleting record']);
        }
    }

    // Status Change action
    if ($action === 'StatusChange' && isset($_POST['id'])) {
        $id = filter_var($_POST['id'], FILTER_SANITIZE_NUMBER_INT);
        $sql_select = "SELECT status FROM Appointments WHERE AppointmentID = ?";
        $stmt_select = mysqli_prepare($conn, $sql_select);
        mysqli_stmt_bind_param($stmt_select, 'i', $id);
        mysqli_stmt_execute($stmt_select);
        $result_select = mysqli_stmt_get_result($stmt_select);

        if (mysqli_num_rows($result_select) > 0) {
            $row = mysqli_fetch_assoc($result_select);
            $new_status = $row['status'] === 'Active' ? 'Inactive' : 'Active';
            $sql_update = "UPDATE Appointments SET status = ? WHERE AppointmentID = ?";
            $stmt_update = mysqli_prepare($conn, $sql_update);
            mysqli_stmt_bind_param($stmt_update, 'si', $new_status, $id);

            if (mysqli_stmt_execute($stmt_update)) {
                echo json_encode(['status' => $new_status]);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    }
}

// Close the database connection
mysqli_close($conn);
?>
