<?php
// Error reporting for development (set to 0 for production)
error_reporting(E_ALL);
ini_set('display_errors', 1);
date_default_timezone_set("Asia/Calcutta");
$fromdate = date('Y-m-d H:i:s');
include('inc/config.php');
header('Content-Type: application/json');

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? null;

    // Validate the action parameter
    if (!$action) {
        echo json_encode(['status' => 'Error', 'message' => 'Invalid action']);
        exit;
    }

    // Handle Create and Update actions
    if ($action === 'Update') {
        // Sanitize and validate input data
        $name = trim($_POST['Name'] ?? '');
        $email = filter_var($_POST['Email'] ?? '', FILTER_SANITIZE_EMAIL);
        $phone = preg_replace('/[^0-9]/', '', $_POST['Phone'] ?? '');
        $degree = trim($_POST['Degree'] ?? '');
        $address = trim($_POST['Address'] ?? '');
        $extraField1 = trim($_POST['ExtraField1'] ?? '');
        $clinicName = trim($_POST['ClinicName'] ?? '');
        $username = trim($_POST['username'] ?? '');
        $id = $_POST['id'] ?? null;

        // Validate required fields
        if (empty($name) || !filter_var($email, FILTER_VALIDATE_EMAIL) || empty($phone) || empty($username)) {
            echo json_encode(['status' => 'Error', 'message' => 'Required fields are missing or invalid']);
            exit;
        }

        // Handle file upload for ProfilePhoto
        $profilePhoto = null;
        if (isset($_FILES['ProfilePhoto']) && $_FILES['ProfilePhoto']['error'] === UPLOAD_ERR_OK) {
            $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
            if (in_array($_FILES['ProfilePhoto']['type'], $allowedTypes) && $_FILES['ProfilePhoto']['size'] < 2 * 1024 * 1024) {
                $uploadDir = 'iadmin/uploads/';
                $fileName = uniqid() . '_' . basename($_FILES['ProfilePhoto']['name']);
                $filePath = $uploadDir . $fileName;

                if (move_uploaded_file($_FILES['ProfilePhoto']['tmp_name'], $filePath)) {
                    $profilePhoto = $fileName;
                } else {
                    echo json_encode(['status' => 'Error', 'message' => 'File upload failed']);
                    exit;
                }
            } else {
                echo json_encode(['status' => 'Error', 'message' => 'Invalid file type or size']);
                exit;
            }
        }

        if ($id) {
            // Check for duplicate email or phone
            $stmt = $conn->prepare("SELECT * FROM Doctors WHERE (Email = ? OR Phone = ? OR Username  = ?) AND DoctorID != ?");
            $stmt->bind_param("sssi", $email, $phone,$username, $id);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                echo json_encode(['status' => 'Error', 'message' => 'Email or Phone or Username already exists']);
                exit;
            }

            // Fetch current profile photo if a new one is uploaded
            $oldPhoto = null;
            if ($profilePhoto) {
                $stmt = $conn->prepare("SELECT ProfilePhoto FROM Doctors WHERE DoctorID = ?");
                $stmt->bind_param("i", $id);
                $stmt->execute();
                $result = $stmt->get_result();

                if ($result->num_rows > 0) {
                    $row = $result->fetch_assoc();
                    $oldPhoto = $row['ProfilePhoto'];
                }
            }

            // Update doctor details
            $query = "UPDATE Doctors SET Name = ?, Email = ?, Phone = ?,Username = ?, Degree = ?, Address = ?, ExtraField1 = ?, ClinicName = ?, Updatedat = ?";
            $params = [$name, $email, $phone,$username, $degree, $address, $extraField1, $clinicName, $fromdate];
            $types = "sssssssss";

            if ($profilePhoto) {
                $query .= ", ProfilePhoto = ?";
                $params[] = $profilePhoto;
                $types .= "s";
            }
            $query .= " WHERE DoctorID = ?";
            $params[] = $id;
            $types .= "i";

            $stmt = $conn->prepare($query);
            $stmt->bind_param($types, ...$params);

            if ($stmt->execute()) {
                // Delete old profile photo if a new one was uploaded
                if ($profilePhoto && $oldPhoto) {
                    $oldPhotoPath = 'iadmin/uploads/' . $oldPhoto;
                    if (file_exists($oldPhotoPath)) {
                        unlink($oldPhotoPath); // Delete the old photo
                    }
                }
                echo json_encode(['status' => 'Update']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => $stmt->error]);
            }
        }
    }

    // Select doctor by ID
    elseif ($action === 'Select' && isset($_POST['id'])) {
        $id = (int) $_POST['id'];
        

        $stmt = $conn->prepare("SELECT * FROM Doctors WHERE DoctorID = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            if (isset($row['ProfilePhoto'])) {
                $row['ProfilePhoto'] = $row['ProfilePhoto'] ? 'iadmin/uploads/' . $row['ProfilePhoto'] : null;
            }
            echo json_encode($row);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    } else {
        echo json_encode(['status' => 'Error', 'message' => 'Invalid action']);
    }
}

// Close the database connection
mysqli_close($conn);
?>
