<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

date_default_timezone_set("Asia/Calcutta");

$fromdate = date('Y-m-d H:i:s');

// Include database configuration file
include('inc/config.php');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'];
    $id = $_POST['id'] ?? null;

    // Sanitize input
    $uniqueID = mysqli_real_escape_string($conn, $_POST['UniqueID'] ?? mt_rand(1000000, 9999999));
    $FirstName = mysqli_real_escape_string($conn, $_POST['FirstName'] ?? '');
    $LastName = mysqli_real_escape_string($conn, $_POST['LastName'] ?? '');
    $Email = mysqli_real_escape_string($conn, $_POST['Email'] ?? '');
    $Phone = mysqli_real_escape_string($conn, $_POST['Phone'] ?? '');
    $Username = mysqli_real_escape_string($conn, $_POST['Username'] ?? '');
    $password = mysqli_real_escape_string($conn, $_POST['adminpassword'] ?? '');
    $HireDate = mysqli_real_escape_string($conn, $_POST['HireDate'] ?? '');
    $Address = mysqli_real_escape_string($conn, $_POST['Address'] ?? '');
    $JobTitle = mysqli_real_escape_string($conn, $_POST['JobTitle'] ?? '');
    $useridnew = mysqli_real_escape_string($conn, $_POST['useridnew'] ?? '');

    // Action handling
    if ($action === 'Create') {

        // Hash password before storing
        $hashed_password = password_hash($password, PASSWORD_DEFAULT);

        // Check for duplicates using prepared statement
        $checkDuplicate = "SELECT * FROM Employees WHERE UniqueID = ? OR Email = ? OR Phone = ? OR Username = ?";
        $stmt_check = mysqli_prepare($conn, $checkDuplicate);
        mysqli_stmt_bind_param($stmt_check, 'ssss', $uniqueID, $Email, $Phone, $Username);
        mysqli_stmt_execute($stmt_check);
        $duplicateResult = mysqli_stmt_get_result($stmt_check);

        if (mysqli_num_rows($duplicateResult) > 0) {
            echo json_encode(['status' => 'Error', 'message' => 'Duplicate record found']);
        } else {
            // Insert new record using prepared statement
            $insertQuery = "INSERT INTO Employees (DoctorID, UniqueID, FirstName, LastName, Email, Phone, Username, Password, HireDate, Address, JobTitle, Role, Status, CreatedAt)
                            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, 'Employee', 1, ?)";
            $stmt = mysqli_prepare($conn, $insertQuery);
            mysqli_stmt_bind_param($stmt, 'isssssssssss', $useridnew, $uniqueID, $FirstName, $LastName, $Email, $Phone, $Username, $hashed_password, $HireDate, $Address, $JobTitle, $fromdate);
            
            if (mysqli_stmt_execute($stmt)) {
                echo json_encode(['status' => 'Create']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        }
    } elseif ($action === 'Update' && $id) {
        // Check for duplicates excluding the current record using prepared statement
        $checkDuplicate = "SELECT * FROM Employees WHERE (UniqueID = ? OR Email = ? OR Phone = ? OR Username = ?) AND EmployeeID != ?";
        $stmt_check = mysqli_prepare($conn, $checkDuplicate);
        mysqli_stmt_bind_param($stmt_check, 'ssssi', $uniqueID, $Email, $Phone, $Username, $id);
        mysqli_stmt_execute($stmt_check);
        $duplicateResult = mysqli_stmt_get_result($stmt_check);

        if (mysqli_num_rows($duplicateResult) > 0) {
            echo json_encode(['status' => 'Error', 'message' => 'Duplicate record found']);
        } else {
            // Update record using prepared statement
            $updateQuery = "UPDATE Employees SET FirstName = ?, LastName = ?, Email = ?, Phone = ?, Username = ?, HireDate = ?, Address = ?, JobTitle = ?, UpdatedAt = ? WHERE EmployeeID = ?";
            $stmt_update = mysqli_prepare($conn, $updateQuery);
            mysqli_stmt_bind_param($stmt_update, 'ssssssssis', $FirstName, $LastName, $Email, $Phone, $Username, $HireDate, $Address, $JobTitle, $fromdate, $id);

            if (mysqli_stmt_execute($stmt_update)) {
                echo json_encode(['status' => 'Update']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        }
    } elseif ($action === 'Select' && $id) {
        // Fetch a record using prepared statement
        $query = "SELECT * FROM Employees WHERE EmployeeID = ?";
        $stmt = mysqli_prepare($conn, $query);
        mysqli_stmt_bind_param($stmt, 'i', $id);
        mysqli_stmt_execute($stmt);
        $result = mysqli_stmt_get_result($stmt);

        if ($result && mysqli_num_rows($result) > 0) {
            $row = mysqli_fetch_assoc($result);
            echo json_encode($row);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    } elseif ($action === 'Delete' && $id) {
        // Delete a record using prepared statement
        $sql_delete = "DELETE FROM Employees WHERE EmployeeID = ?";
        $stmt_delete = mysqli_prepare($conn, $sql_delete);
        mysqli_stmt_bind_param($stmt_delete, 'i', $id);

        if (mysqli_stmt_execute($stmt_delete)) {
            echo json_encode(['status' => 'Delete', 'message' => 'Record deleted successfully']);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Error deleting record']);
        }
    } elseif ($action === 'StatusChange' && $id) {
        // Toggle status using prepared statement
        $sql_select = "SELECT Status FROM Employees WHERE EmployeeID = ?";
        $stmt_select = mysqli_prepare($conn, $sql_select);
        mysqli_stmt_bind_param($stmt_select, 'i', $id);
        mysqli_stmt_execute($stmt_select);
        $result_select = mysqli_stmt_get_result($stmt_select);

        if (mysqli_num_rows($result_select) > 0) {
            $row = mysqli_fetch_assoc($result_select);
            $new_status = $row['Status'] == 1 ? 0 : 1;
            $sql_update = "UPDATE Employees SET Status = ? WHERE EmployeeID = ?";
            $stmt_update = mysqli_prepare($conn, $sql_update);
            mysqli_stmt_bind_param($stmt_update, 'ii', $new_status, $id);

            if (mysqli_stmt_execute($stmt_update)) {
                echo json_encode(['status' => 'StatusChange', 'message' => 'Status updated successfully']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => 'Error updating status']);
            }
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    }
}

// Close database connection
mysqli_close($conn);
?>
