<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include database configuration file
include('inc/config.php');

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        $action = $_POST['action'];

        // Handle Create and Update actions
        if ($action === 'Create' || $action === 'Update') {
            if (isset($_POST['fullname']) && isset($_POST['mobile']) && isset($_POST['username'])) {
                // Sanitize inputs
                $fullname = mysqli_real_escape_string($conn, $_POST['fullname']);
                $mobile = mysqli_real_escape_string($conn, $_POST['mobile']);
                $email = isset($_POST['email']) ? mysqli_real_escape_string($conn, $_POST['email']) : '';
                $adminuser = mysqli_real_escape_string($conn, $_POST['username']);
                $role = isset($_POST['role']) ? mysqli_real_escape_string($conn, $_POST['role']) : '';
                $id = isset($_POST['id']) ? $_POST['id'] : '';

                // Check if mobile number, username or email already exists
                $sql_check = "SELECT * FROM Users WHERE (Mobile = ? OR Email = ? OR Username = ?) " . ($action === 'Update' ? "AND UserID != ?" : "");
                $stmt_check = mysqli_prepare($conn, $sql_check);
                
                // Bind parameters
                if ($action === 'Update') {
                    mysqli_stmt_bind_param($stmt_check, 'sssi', $mobile, $email, $adminuser, $id);
                } else {
                    mysqli_stmt_bind_param($stmt_check, 'sss', $mobile, $email, $adminuser);
                }
                
                mysqli_stmt_execute($stmt_check);
                $result_check = mysqli_stmt_get_result($stmt_check);

                if (mysqli_num_rows($result_check) > 0) {
                    echo 'Duplicate';
                } else {
                    // Handle password only if it is a Create action
                    if ($action === 'Create' && isset($_POST['password']) && $_POST['password'] !== '') {
                        $password = $_POST['password'];
                        // Hash password before inserting
                        $hashed_password = password_hash($password, PASSWORD_DEFAULT);
                    } elseif ($action === 'Update') {
                        $hashed_password = null; // No need to update password during an update
                    } else {
                        echo 'Password is required.';
                        exit;
                    }

                    $created_at = date('Y-m-d H:i:s'); // Current date and time
                    if ($action === 'Create') {
                        // Insert new user
                        $sql_insert = "INSERT INTO Users (Username, PasswordHash, Role, FullName, Mobile, Email, Status, CreatedAt) 
                                       VALUES (?, ?, ?, ?, ?, ?, 1, ?)";
                        $stmt_insert = mysqli_prepare($conn, $sql_insert);
                        mysqli_stmt_bind_param($stmt_insert, 'sssssss', $adminuser, $hashed_password, $role, $fullname, $mobile, $email, $created_at);
                        
                        if (mysqli_stmt_execute($stmt_insert)) {
                            echo 'Create';
                        } else {
                            echo 'Error';
                        }
                    } elseif ($action === 'Update') {
                        // Update existing user (without updating password)
                        if ($hashed_password !== null) {
                            $sql_update = "UPDATE Users SET FullName = ?, Mobile = ?, Email = ?, Username = ?, PasswordHash = ?, UpdatedAt = ? WHERE UserID = ?";
                            $stmt_update = mysqli_prepare($conn, $sql_update);
                            mysqli_stmt_bind_param($stmt_update, 'ssssssi', $fullname, $mobile, $email, $adminuser, $hashed_password, $created_at, $id);
                        } else {
                            $sql_update = "UPDATE Users SET FullName = ?, Mobile = ?, Email = ?, Username = ?, UpdatedAt = ? WHERE UserID = ?";
                            $stmt_update = mysqli_prepare($conn, $sql_update);
                            mysqli_stmt_bind_param($stmt_update, 'sssssi', $fullname, $mobile, $email, $adminuser, $created_at, $id);
                        }

                        if (mysqli_stmt_execute($stmt_update)) {
                            echo 'Update';
                        } else {
                            echo 'Error';
                        }
                    }
                }
            } else {
                echo 'All Fields are Required';
            }
        } elseif ($action === 'Select') {
            // Handle Select action
            if (isset($_POST['id'])) {
                $id = $_POST['id'];
                $sql_select = "SELECT * FROM Users WHERE UserID = ?";
                $stmt_select = mysqli_prepare($conn, $sql_select);
                mysqli_stmt_bind_param($stmt_select, 'i', $id);
                mysqli_stmt_execute($stmt_select);
                $result_select = mysqli_stmt_get_result($stmt_select);

                if (mysqli_num_rows($result_select) > 0) {
                    $row = mysqli_fetch_assoc($result_select);
                    echo json_encode($row);
                } else {
                    echo 'Error';
                }
            } else {
                echo 'ID is Required';
            }
        } elseif ($action === 'Delete') {
            // Handle Delete action
            if (isset($_POST['id'])) {
                $id = $_POST['id'];
                $sql_delete = "DELETE FROM Users WHERE UserID = ?";
                $stmt_delete = mysqli_prepare($conn, $sql_delete);
                mysqli_stmt_bind_param($stmt_delete, 'i', $id);
                if (mysqli_stmt_execute($stmt_delete)) {
                    echo 'Delete';
                } else {
                    echo 'Error';
                }
            } else {
                echo 'ID is Required';
            }
        } elseif ($action === 'StatusChange') {
    if (isset($_POST['id'])) {
        $id = $_POST['id'];
        $sql_select = "SELECT Status FROM Users WHERE UserID = ?";
        $stmt_select = mysqli_prepare($conn, $sql_select);
        mysqli_stmt_bind_param($stmt_select, 'i', $id);

        if (mysqli_stmt_execute($stmt_select)) {
            $result_select = mysqli_stmt_get_result($stmt_select);

            if (mysqli_num_rows($result_select) > 0) {
                $row = mysqli_fetch_assoc($result_select);
                $current_status = $row['Status'];
                $new_status = $current_status == 1 ? 0 : 1;

                $sql_update = "UPDATE Users SET Status = ? WHERE UserID = ?";
                $stmt_update = mysqli_prepare($conn, $sql_update);
                mysqli_stmt_bind_param($stmt_update, 'ii', $new_status, $id);

                if (mysqli_stmt_execute($stmt_update)) {
                    echo json_encode(['status' => 'Status Updated', 'newStatus' => $new_status]);
                } else {
                    echo json_encode(['status' => 'Error updating status']);
                }
            } else {
                echo json_encode(['status' => 'User not found']);
            }
        } else {
            echo json_encode(['status' => 'Error executing select query']);
        }
    } else {
        echo json_encode(['status' => 'ID is Required']);
    }
    }


    } else {
        echo 'Action is Required';
    }
} else {
    echo 'Invalid Request Method';
}
?>
