<?php
error_reporting(E_ALL);
ini_set('display_errors', 0); // Disable displaying errors in production
date_default_timezone_set("Asia/Calcutta"); // India time (GMT+5:30)

$fromdate = date('Y-m-d H:i:s');
$month = date('F');
$financial_year = (date('m') >= 4) ? date('Y') . '-' . substr((date('Y') + 1), -2) : (date('Y') - 1) . '-' . substr(date('Y'), -2);

// Include database configuration file
include('inc/config.php');

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $action = $_POST['action'];

    // Handle the select action
    if ($action == 'Select') {
        $id = $_POST['id'];

        if (is_numeric($id)) {
            $query = "SELECT * FROM Doctorholidays WHERE HolidayID = ?";
            $stmt = mysqli_prepare($conn, $query);
            mysqli_stmt_bind_param($stmt, 'i', $id);
            mysqli_stmt_execute($stmt);
            $result = mysqli_stmt_get_result($stmt);

            if ($result) {
                $data = mysqli_fetch_assoc($result);
                echo json_encode($data);
            } else {
                echo json_encode(['error' => 'Error fetching data']);
            }
        } else {
            echo json_encode(['error' => 'Invalid ID']);
        }
        exit();
    }

    // Handle the create action
    if ($action == 'Create') {
        $doctor_id = $_POST['doctor_id'];
        $leave_date = $_POST['leave_date'];
        $Shift = $_POST['Shift'];
        $reason = $_POST['reason'];
        $useridnew = $_POST['useridnew'];
        $rolenew = $_POST['rolenew'];

        if (is_numeric($doctor_id) && is_numeric($useridnew) && is_string($reason) && !empty($leave_date)) {
            $sql_check = "SELECT * FROM Doctorholidays WHERE DoctorID = ? AND LeaveDate = ?";
            $stmt_check = mysqli_prepare($conn, $sql_check);
            mysqli_stmt_bind_param($stmt_check, 'is', $doctor_id, $leave_date);
            mysqli_stmt_execute($stmt_check);
            $result_check = mysqli_stmt_get_result($stmt_check);

            if (mysqli_num_rows($result_check) > 0) {
                echo 'Duplicate';
            } else {
                $query = "INSERT INTO Doctorholidays (DoctorID, LeaveDate, Shift, Reason, status, UserId, UserRole, created_at) 
                          VALUES (?, ?, ?, ?, 'On Leave', ?, ?, ?)";
                $stmt = mysqli_prepare($conn, $query);
                mysqli_stmt_bind_param($stmt, 'isssiss', $doctor_id, $leave_date, $Shift, $reason, $useridnew, $rolenew, $fromdate);

                if (mysqli_stmt_execute($stmt)) {
                    echo 'Create';
                } else {
                    echo 'Error';
                }
            }
        } else {
            echo 'Invalid input data';
        }
        exit();
    }

    // Handle the update action
    if ($action == 'Update') {
        $id = $_POST['id'];
        $doctor_id = $_POST['doctor_id'];
        $leave_date = $_POST['leave_date'];
        $Shift = $_POST['Shift'];
        $reason = $_POST['reason'];

        if (is_numeric($id) && is_numeric($doctor_id) && is_string($reason) && !empty($leave_date)) {
            $sql_check = "SELECT * FROM Doctorholidays WHERE DoctorID = ? AND LeaveDate = ? AND HolidayID != ?";
            $stmt_check = mysqli_prepare($conn, $sql_check);
            mysqli_stmt_bind_param($stmt_check, 'isi', $doctor_id, $leave_date, $id);
            mysqli_stmt_execute($stmt_check);
            $result_check = mysqli_stmt_get_result($stmt_check);

            if (mysqli_num_rows($result_check) > 0) {
                echo 'Duplicate';
            } else {
                $query = "UPDATE Doctorholidays SET Reason = ?, LeaveDate = ?, Shift = ? WHERE HolidayID = ?";
                $stmt = mysqli_prepare($conn, $query);
                mysqli_stmt_bind_param($stmt, 'sssi', $reason, $leave_date, $Shift, $id);

                if (mysqli_stmt_execute($stmt)) {
                    echo 'Update';
                } else {
                    echo 'Error';
                }
            }
        } else {
            echo 'Invalid input data';
        }
        exit();
    }

    // Handle the delete action
    if ($action == 'Delete') {
        $id = $_POST['id'];

        if (is_numeric($id)) {
            $query = "DELETE FROM Doctorholidays WHERE HolidayID = ?";
            $stmt = mysqli_prepare($conn, $query);
            mysqli_stmt_bind_param($stmt, 'i', $id);
            $result = mysqli_stmt_execute($stmt);

            if ($result) {
                echo 'Delete';
            } else {
                echo 'Error';
            }
        } else {
            echo 'Invalid ID';
        }
        exit();
    }
}
?>
