<?php
ini_set('display_errors', 1); // Show errors (for development)
error_reporting(E_ALL);       // Report all errors
ini_set('log_errors', 1);
date_default_timezone_set("Asia/Calcutta"); // India time (GMT+5:30)

$fromdate = date('Y-m-d H:i:s');
$month = date('F');
$financial_year = (date('m') >= 4) ? date('Y') . '-' . substr((date('Y') + 1), -2) : (date('Y') - 1) . '-' . substr(date('Y'), -2);

// Include database configuration file
include('inc/config.php');

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $action = $_POST['action'];

    // Handle the select action
    if ($action == 'Select') {
        $id = $_POST['id'];

        if (is_numeric($id)) {
            $query = "SELECT * FROM Doctorschedules WHERE ScheduleID = ?";
            $stmt = mysqli_prepare($conn, $query);
            mysqli_stmt_bind_param($stmt, 'i', $id);
            mysqli_stmt_execute($stmt);
            $result = mysqli_stmt_get_result($stmt);

            if ($result) {
                $data = mysqli_fetch_assoc($result);
                echo json_encode($data);
            } else {
                echo json_encode(['error' => 'Error fetching data']);
            }
        } else {
            echo json_encode(['error' => 'Invalid ID']);
        }
        exit();
    }

    // Handle the create action
if ($action == 'Create') {
    $doctor_id = $_POST['doctor_id'];
    $day_of_week = $_POST['day_of_week']; // This should be 'Monday', 'Tuesday', etc.
    $shift_number = $_POST['shift_number'];
    $start_time = $_POST['start_time'];
    $end_time = $_POST['end_time'];
    $appointment_interval = $_POST['appointment_interval'];
    $useridnew = $_POST['useridnew'];
    $rolenew = $_POST['rolenew'];

    // Validate inputs
    if (is_numeric($doctor_id) && is_numeric($shift_number) && is_numeric($useridnew) && !empty($start_time) && !empty($end_time) && in_array($day_of_week, ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday'])) {
        
        if ($start_time >= $end_time) {
            echo json_encode(['status' => 'error', 'message' => 'Start time cannot be the same as or later than end time']);
            exit();
        }

        // Check for duplicate entry
        $sql_check = "SELECT * FROM Doctorschedules WHERE DoctorID = ? AND DayOfWeek = ? AND ShiftNumber = ?";
        $stmt_check = mysqli_prepare($conn, $sql_check);
        mysqli_stmt_bind_param($stmt_check, 'isi', $doctor_id, $day_of_week, $shift_number);
        mysqli_stmt_execute($stmt_check);
        $result_check = mysqli_stmt_get_result($stmt_check);

        if (mysqli_num_rows($result_check) > 0) {
            echo json_encode(['status' => 'error', 'message' => 'Duplicate schedule']);
        } else {
            // Insert schedule into the database
            $query = "INSERT INTO Doctorschedules (DoctorID, DayOfWeek, ShiftNumber, StartTime, EndTime, AppointmentInterval, UserId, UserRole, created_at) 
                      VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";
            $stmt = mysqli_prepare($conn, $query);

            // Bind parameters: 's' for string (DayOfWeek), 'i' for integers (DoctorID, ShiftNumber, UserId)
            mysqli_stmt_bind_param($stmt, 'isissiiss', $doctor_id, $day_of_week, $shift_number, $start_time, $end_time, $appointment_interval, $useridnew, $rolenew, $fromdate);

            if (mysqli_stmt_execute($stmt)) {
                // Success response
                echo json_encode(['status' => 'success', 'message' => 'Schedule Saved Successfully']); 
            } else {
                // Failure response
                echo json_encode(['status' => 'error', 'message' => 'Error while saving schedule']);
            }
        }
    } else {
        echo json_encode(['status' => 'error', 'message' => 'Invalid input data or invalid Day of Week']);
    }
    exit();
}



    // Handle the update action
    if ($action == 'Update') {
        $id = $_POST['id'];
        $doctor_id = $_POST['doctor_id'];
        $day_of_week = $_POST['day_of_week'];
        $shift_number = $_POST['shift_number'];
        $start_time = $_POST['start_time'];
        $end_time = $_POST['end_time'];
        $appointment_interval = $_POST['appointment_interval'];

        // Validate inputs
        if (is_numeric($id) && is_numeric($doctor_id) && is_numeric($shift_number) && !empty($start_time) && !empty($end_time)) {
            
            if ($start_time >= $end_time) {
            echo json_encode(['status' => 'error', 'message' => 'Start time cannot be the same as or later than end time']);
            exit();
        }
            // Check for duplicate entry (excluding current record)
            $sql_check = "SELECT * FROM Doctorschedules WHERE DoctorID = ? AND DayOfWeek = ? AND ShiftNumber = ? AND ScheduleID != ?";
            $stmt_check = mysqli_prepare($conn, $sql_check);
            mysqli_stmt_bind_param($stmt_check, 'isii', $doctor_id, $day_of_week, $shift_number, $id);
            mysqli_stmt_execute($stmt_check);
            $result_check = mysqli_stmt_get_result($stmt_check);

            if (mysqli_num_rows($result_check) > 0) {
                 echo json_encode(['status' => 'error', 'message' => 'Duplicate']);
            } else {
                // Update the schedule in the database
                $query = "UPDATE Doctorschedules SET DayOfWeek = ?, ShiftNumber = ?, StartTime = ?, EndTime = ?, AppointmentInterval = ? WHERE ScheduleID = ?";
                $stmt = mysqli_prepare($conn, $query);
                mysqli_stmt_bind_param($stmt, 'sisssi', $day_of_week, $shift_number, $start_time, $end_time, $appointment_interval, $id);

                if (mysqli_stmt_execute($stmt)) {
                    echo json_encode(['status' => 'success', 'message' => 'Schedule Updated Successfully']);
                } else {
                    echo json_encode(['status' => 'error', 'message' => 'Error while updating schedule']);
                }
            }
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Invalid input data']);
        }
        exit();
    }

    // Handle the delete action
    if ($action == 'Delete') {
        $id = $_POST['id'];

        if (is_numeric($id)) {
            // Delete the schedule record
            $query = "DELETE FROM Doctorschedules WHERE ScheduleID = ?";
            $stmt = mysqli_prepare($conn, $query);
            mysqli_stmt_bind_param($stmt, 'i', $id);
            $result = mysqli_stmt_execute($stmt);

            if ($result) {
                echo json_encode(['status' => 'success', 'message' => 'Schedule Deleted Successfully']);
            } else {
                echo json_encode(['status' => 'error', 'message' => 'Error while deleting schedule']);
            }
        } else {
            echo json_encode(['status' => 'error', 'message' => 'Invalid ID']);
        }
        exit();
    }
}
?>
