<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Medicine Multi-Select Dropdown with Search</title>
    <link href="https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" />
    <style>
        .multi-select-container {
            max-width: 500px;
            margin: 20px auto;
        }

        .selected-medicines {
            margin-top: 15px;
            padding: 5px;
        }

        .selected-medicines span {
            display: inline-block;
            background-color: #007bff;
            color: #fff;
            padding: 5px 10px;
            border-radius: 15px;
            margin: 5px;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="multi-select-container">
            <label for="medicine">Search and Select Medicines</label>
            <select id="medicine" class="form-control" multiple="multiple"></select>
        </div>
        <div class="selected-medicines" id="selectedMedicines">
            <strong>Selected Medicines:</strong>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/js/select2.min.js"></script>
    <script>
        $(document).ready(function () {
            // Initialize Select2 for multi-select dropdown
            $('#medicine').select2({
                placeholder: "Search medicine",
                minimumInputLength: 1,
                ajax: {
                    url: 'autocomplete_medicine.php',  // PHP backend for medicine search
                    dataType: 'json',
                    data: function (params) {
                        return {
                            term: params.term // Send search term
                        };
                    },
                    processResults: function (data) {
                        // Process and format the response from the backend
                        return {
                            results: data.map(function (medicine) {
                                return {
                                    id: medicine,  // Value for the option
                                    text: medicine  // Text displayed in the dropdown
                                };
                            })
                        };
                    }
                }
            });

            // Event listener when the selection changes (for selected medicines)
            $('#medicine').on('change', function () {
                const selectedMedicines = $(this).val();
                updateSelectedMedicines(selectedMedicines);
            });

            // Update the selected medicines UI
            function updateSelectedMedicines(medicines) {
                const container = $('#selectedMedicines');
                container.html('<strong>Selected Medicines:</strong>');

                medicines.forEach(function (medicine) {
                    container.append(`<span>${medicine}</span>`);
                });
            }
        });
    </script>
</body>
</html>
