<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

date_default_timezone_set("Asia/Calcutta");
$fromdate = date('Y-m-d H:i:s');

// Include database configuration file
include('inc/config.php');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'];

    // Create and Update Actions
    if ($action === 'Create' || $action === 'Update') {
        // Sanitize and collect form data (Make sure inputs are valid!)
        $medicine_name = $_POST['medicine_name'];
        $contains = $_POST['contains'];
        $usage_method = $_POST['usage_method'];
        $form = $_POST['form'];
        $status = $_POST['status'];
        $useridnew = $_POST['useridnew'];
        $rolenew = $_POST['rolenew'];

        $id = $_POST['id'] ?? null;

        // Input Validation - Ensure non-empty fields
        if (empty($medicine_name) || empty($contains) || empty($usage_method) || empty($form) || empty($status)) {
            echo json_encode(['status' => 'Error', 'message' => 'All fields are required.']);
            exit;
        }

        // Insert action
        if ($action === 'Create') {
            $insertQuery = "INSERT INTO Medicines (MedicineName, Contains, Form, UsageMethod, Status, created_at, UserId, UserRole)
                            VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
            $stmt = mysqli_prepare($conn, $insertQuery);
            mysqli_stmt_bind_param($stmt, 'ssssssss', $medicine_name, $contains, $form, $usage_method, $status, $fromdate, $useridnew, $rolenew);

            if (mysqli_stmt_execute($stmt)) {
                echo json_encode(['status' => 'Create']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        }

        // Update action
        elseif ($action === 'Update' && $id) {
            $updateQuery = "UPDATE Medicines SET MedicineName = ?, Contains = ?, Form = ?, UsageMethod = ?, Status = ? WHERE MedicineID = ?";
            $stmt = mysqli_prepare($conn, $updateQuery);
            mysqli_stmt_bind_param($stmt, 'sssssi', $medicine_name, $contains, $form, $usage_method, $status, $id);

            if (mysqli_stmt_execute($stmt)) {
                echo json_encode(['status' => 'Update']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        }
    }

    // Select action
    if ($action === 'Select' && isset($_POST['id'])) {
        $id = $_POST['id'];
        $query = "SELECT * FROM Medicines WHERE MedicineID = ?";
        $stmt = mysqli_prepare($conn, $query);
        mysqli_stmt_bind_param($stmt, 'i', $id);
        mysqli_stmt_execute($stmt);
        $result = mysqli_stmt_get_result($stmt);

        if ($result && mysqli_num_rows($result) > 0) {
            $row = mysqli_fetch_assoc($result);
            echo json_encode($row);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found.']);
        }
    }

    // Delete action
    if ($action === 'Delete' && isset($_POST['id'])) {
        $id = $_POST['id'];
        $sql_delete = "DELETE FROM Medicines WHERE MedicineID = ?";
        $stmt = mysqli_prepare($conn, $sql_delete);
        mysqli_stmt_bind_param($stmt, 'i', $id);

        if (mysqli_stmt_execute($stmt)) {
            echo json_encode(['status' => 'Delete', 'message' => 'Record deleted successfully']);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Error deleting record']);
        }
    }

    // Status Change action
    if ($action === 'StatusChange' && isset($_POST['id'])) {
        $id = $_POST['id'];
        $sql_select = "SELECT status FROM Medicines WHERE MedicineID = ?";
        $stmt = mysqli_prepare($conn, $sql_select);
        mysqli_stmt_bind_param($stmt, 'i', $id);
        mysqli_stmt_execute($stmt);
        $result_select = mysqli_stmt_get_result($stmt);

        if (mysqli_num_rows($result_select) > 0) {
            $row = mysqli_fetch_assoc($result_select);
            $new_status = $row['status'] === 'Active' ? 'Inactive' : 'Active';
            $sql_update = "UPDATE Medicines SET status = ? WHERE MedicineID = ?";
            $stmt_update = mysqli_prepare($conn, $sql_update);
            mysqli_stmt_bind_param($stmt_update, 'si', $new_status, $id);

            if (mysqli_stmt_execute($stmt_update)) {
                echo json_encode(['status' => $new_status]);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    }
}

// Close the database connection
mysqli_close($conn);
?>
