<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

date_default_timezone_set("Asia/Calcutta");
$fromdate = date('Y-m-d H:i:s');

// Include database configuration file
include('inc/config.php');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'];

    if ($action === 'Create' || $action === 'Update') {
        // Sanitize and collect form data
        $doctor_id = $_POST['doctor_id'] ?? null;
        $patient_id = $_POST['patient_id'] ?? null;
        $appointment_id = $_POST['appointment_id'] ?? null;
        $medicineIds = isset($_POST['MedicineID']) && is_array($_POST['MedicineID']) ? $_POST['MedicineID'] : [];
        $dosage = $_POST['Dosage'] ?? '';
        $reports = $_POST['ReportsName'] ?? '';
        $special_note = $_POST['SpecialNote'] ?? '';
        $id = $_POST['id'] ?? null;
        $useridnew = $_POST['useridnew'] ?? null;
        $rolenew = $_POST['rolenew'] ?? null;

        if (empty($medicineIds)) {
            echo json_encode(['status' => 'Error', 'message' => 'No medicines selected']);
            exit;
        }

        // Sanitize medicine IDs (ensure integers only)
        $medicineIdsString = implode(',', array_map('intval', $medicineIds));

        // Fetch selected medicines
        $fetchMedicinesQuery = "SELECT MedicineID, MedicineName FROM Medicines WHERE MedicineID IN ($medicineIdsString)";
        $result = mysqli_query($conn, $fetchMedicinesQuery);
        $medicineNames = [];
        while ($row = mysqli_fetch_assoc($result)) {
            $medicineNames[] = $row['MedicineName'];
        }
        $medicineNamesString = implode(',', $medicineNames);

        // Create action
        if ($action === 'Create') {
            
            $regDate = date('Y-m-d');
            // Check for duplicates
            $checkDuplicate = "SELECT * FROM Prescriptions WHERE DoctorID = ? AND PatientID = ? AND AppointmentID = ?";
            $stmt_check = mysqli_prepare($conn, $checkDuplicate);
            mysqli_stmt_bind_param($stmt_check, 'iii', $doctor_id, $patient_id, $appointment_id);
            mysqli_stmt_execute($stmt_check);
            $duplicateResult = mysqli_stmt_get_result($stmt_check);

            if (mysqli_num_rows($duplicateResult) > 0) {
                echo json_encode(['status' => 'Duplicate', 'message' => 'A prescription for this appointment already exists.']);
                exit;
            }

            // Insert new prescription
            $insertQuery = "INSERT INTO Prescriptions (AppointmentID, DoctorID, PatientID, Medicine, Dosage, Date, SpecialNote, ReportsName, created_at, UserId, UserRole)
                            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
            $stmt_insert = mysqli_prepare($conn, $insertQuery);
            mysqli_stmt_bind_param($stmt_insert, 'iiissssssss', $appointment_id, $doctor_id, $patient_id, $medicineNamesString, $dosage,$regDate, $special_note, $reports,$fromdate, $useridnew, $rolenew);
            if (mysqli_stmt_execute($stmt_insert)) {
                $prescriptionID = mysqli_insert_id($conn);

                // Insert medicines for the prescription
                foreach ($medicineIds as $medicineID) {
                    $insertMedicineQuery = "INSERT INTO Prescriptions_Medicines (PrescriptionID, MedicineID) VALUES (?, ?)";
                    $stmt_medicine = mysqli_prepare($conn, $insertMedicineQuery);
                    mysqli_stmt_bind_param($stmt_medicine, 'ii', $prescriptionID, $medicineID);
                    mysqli_stmt_execute($stmt_medicine);
                }

                echo json_encode(['status' => 'Create']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        }

        // Update action
        elseif ($action === 'Update' && $id) {
            // Check for duplicate in rescheduled appointment
            $checkDuplicate = "SELECT * FROM Prescriptions WHERE DoctorID = ? AND PatientID = ? AND AppointmentID = ? AND PrescriptionID != ?";
            $stmt_check = mysqli_prepare($conn, $checkDuplicate);
            mysqli_stmt_bind_param($stmt_check, 'iiii', $doctor_id, $patient_id, $appointment_id, $id);
            mysqli_stmt_execute($stmt_check);
            $duplicateResult = mysqli_stmt_get_result($stmt_check);

            if (mysqli_num_rows($duplicateResult) > 0) {
                echo json_encode(['status' => 'Duplicate', 'message' => 'Another Prescription already exists with the same details.']);
                exit;
            }

            // Update prescription
            $updateQuery = "UPDATE Prescriptions SET DoctorID = ?, PatientID = ?, AppointmentID = ?, Medicine = ?, Dosage = ?, SpecialNote = ?, ReportsName = ? WHERE PrescriptionID = ?";
            $stmt_update = mysqli_prepare($conn, $updateQuery);
            mysqli_stmt_bind_param($stmt_update, 'iiissssi', $doctor_id, $patient_id, $appointment_id, $medicineNamesString, $dosage, $special_note, $reports, $id);
            if (mysqli_stmt_execute($stmt_update)) {
                // Remove old medicines before inserting new ones
                $deleteOldMedicinesQuery = "DELETE FROM Prescriptions_Medicines WHERE PrescriptionID = ?";
                $stmt_delete = mysqli_prepare($conn, $deleteOldMedicinesQuery);
                mysqli_stmt_bind_param($stmt_delete, 'i', $id);
                mysqli_stmt_execute($stmt_delete);

                // Insert new medicines
                foreach ($medicineIds as $medicineID) {
                    $insertMedicineQuery = "INSERT INTO Prescriptions_Medicines (PrescriptionID, MedicineID) VALUES (?, ?)";
                    $stmt_medicine = mysqli_prepare($conn, $insertMedicineQuery);
                    mysqli_stmt_bind_param($stmt_medicine, 'ii', $id, $medicineID);
                    mysqli_stmt_execute($stmt_medicine);
                }

                echo json_encode(['status' => 'Update']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        }
    }

    // Select action
    if ($action === 'Select' && isset($_POST['id'])) {
        $id = $_POST['id'];
        $query = "SELECT p.*, a.AppointmentID, a.Date, a.Time 
                  FROM Prescriptions p 
                  JOIN Appointments a ON p.AppointmentID = a.AppointmentID 
                  WHERE p.PrescriptionID = ?";
        $stmt = mysqli_prepare($conn, $query);
        mysqli_stmt_bind_param($stmt, 'i', $id);
        mysqli_stmt_execute($stmt);
        $result = mysqli_stmt_get_result($stmt);

        if ($result && mysqli_num_rows($result) > 0) {
            $row = mysqli_fetch_assoc($result);
            // Fetch associated medicines for the prescription
            $medicineQuery = "SELECT m.MedicineID, m.MedicineName 
                              FROM Medicines m
                              JOIN Prescriptions_Medicines pm ON m.MedicineID = pm.MedicineID
                              WHERE pm.PrescriptionID = ?";
            $stmt_medicines = mysqli_prepare($conn, $medicineQuery);
            mysqli_stmt_bind_param($stmt_medicines, 'i', $id);
            mysqli_stmt_execute($stmt_medicines);
            $medicineResult = mysqli_stmt_get_result($stmt_medicines);

            $medicines = [];
            if ($medicineResult && mysqli_num_rows($medicineResult) > 0) {
                while ($medicine = mysqli_fetch_assoc($medicineResult)) {
                    $medicines[] = $medicine['MedicineID'];
                }
            }

            $row['Medicines'] = $medicines;
            echo json_encode($row);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found.']);
        }
    }

    // Delete action
    if ($action === 'Delete' && isset($_POST['id'])) {
        $id = $_POST['id'];
        $sql_delete1 = "DELETE FROM Prescriptions_Medicines WHERE PrescriptionID = ?";
        $stmt_delete1 = mysqli_prepare($conn, $sql_delete1);
        mysqli_stmt_bind_param($stmt_delete1, 'i', $id);
        mysqli_stmt_execute($stmt_delete1);

        $sql_delete = "DELETE FROM Prescriptions WHERE PrescriptionID = ?";
        $stmt_delete = mysqli_prepare($conn, $sql_delete);
        mysqli_stmt_bind_param($stmt_delete, 'i', $id);

        if (mysqli_stmt_execute($stmt_delete)) {
            echo json_encode(['status' => 'Delete', 'message' => 'Record deleted successfully']);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Error deleting record']);
        }
    }

    // Status Change action
    if ($action === 'StatusChange' && isset($_POST['id'])) {
        $id = $_POST['id'];
        $sql_select = "SELECT status FROM Prescriptions WHERE PrescriptionID = ?";
        $stmt_select = mysqli_prepare($conn, $sql_select);
        mysqli_stmt_bind_param($stmt_select, 'i', $id);
        mysqli_stmt_execute($stmt_select);
        $result_select = mysqli_stmt_get_result($stmt_select);

        if (mysqli_num_rows($result_select) > 0) {
            $row = mysqli_fetch_assoc($result_select);
            $new_status = $row['status'] === 'Active' ? 'Inactive' : 'Active';
            $sql_update = "UPDATE Prescriptions SET status = ? WHERE PrescriptionID = ?";
            $stmt_update = mysqli_prepare($conn, $sql_update);
            mysqli_stmt_bind_param($stmt_update, 'si', $new_status, $id);

            if (mysqli_stmt_execute($stmt_update)) {
                echo json_encode(['status' => $new_status]);
            } else {
                echo json_encode(['status' => 'Error', 'message' => mysqli_error($conn)]);
            }
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    }
}

// Close the database connection
mysqli_close($conn);
?>
